@@ -1,7 +1,7 @@
 use strict;
 package Parse::CPAN::Meta;
 # ABSTRACT: Parse META.yml and META.json CPAN metadata files
-our $VERSION = '1.4406'; # VERSION
+our $VERSION = '1.4408'; # VERSION
 
 use Carp 'croak';
 
@@ -136,7 +136,7 @@ Parse::CPAN::Meta - Parse META.yml and META.json CPAN metadata files
 
 =head1 VERSION
 
-version 1.4406
+version 1.4408
 
 =head1 SYNOPSIS
 
@@ -279,9 +279,9 @@ You will be notified automatically of any progress on your issue.
 This is open source software.  The code repository is available for
 public review and contribution under the terms of the license.
 
-L<http://github.com/Perl-Toolchain-Gang/Parse-CPAN-Meta>
+L<https://github.com/Perl-Toolchain-Gang/Parse-CPAN-Meta>
 
-  git clone git://github.com/Perl-Toolchain-Gang/Parse-CPAN-Meta.git
+  git clone https://github.com/Perl-Toolchain-Gang/Parse-CPAN-Meta.git
 
 =head1 AUTHORS
 
@@ -311,11 +311,11 @@ Neil Bowers <neil@bowers.com>
 
 =item *
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo Signes <rjbs@cpan.org>
 
 =item *
 
-Steffen Mller <smueller@cpan.org>
+Steffen Mueller <smueller@cpan.org>
 
 =back
 
